@@ -33,6 +33,7 @@ def test_allow_none():
     assert IntField().is_valid_wrap(None) == False
     assert IntField(allow_none=True).wrap(None) == None
     assert IntField(allow_none=True).unwrap(None) == None
+    assert IntField(default=None).unwrap(None) == None
 
 def test_id_attr():
     assert IntField().is_id == False
@@ -132,7 +133,45 @@ def datetime_too_old_test():
 def datetime_value_test():
     s = DateTimeField()
     assert s.wrap(datetime(2009, 7, 9)) == datetime(2009, 7, 9)
-    assert s.unwrap(datetime(2009, 7, 9)) == datetime(2009, 7, 9)
+    assert s.unwrap(datetime(2009, 7, 9)) == datetime(2009, 7, 9), (s.unwrap(datetime(2009, 7, 9)),)
+
+@raises(BadValueException)
+def test_tz_unaware():
+    s = DateTimeField(use_tz=True)
+    s.wrap(datetime.now())
+
+def test_tz_aware():
+    import pytz
+    from mongoalchemy.session import Session
+    from mongoalchemy.document import Document
+    # doc
+    class DocTZ(Document):
+        time = DateTimeField(use_tz=True)
+    class DocNoTZ(Document):
+        time = DateTimeField(use_tz=False)
+
+    # timezone -- choose one where the author doesn't live
+    eastern = pytz.timezone('Australia/Melbourne')
+    utc = pytz.utc
+    # session
+    s = Session.connect('unit-testing', timezone=eastern)
+    s.clear_collection(DocTZ)
+    s.clear_collection(DocNoTZ)
+    # time
+    local = eastern.localize(datetime.now())
+    local = local.replace(microsecond=0)
+    doc = DocTZ(time=local)
+    s.insert(doc)
+
+    doc = s.query(DocTZ).one()
+    assert doc.time == local, (doc.time, local)
+
+    # do the no timezone case for code coverage
+    s.insert(DocNoTZ(time=datetime(2012, 1, 1)))
+    obj = s.query(DocNoTZ).one()
+
+
+
 
 # Anything Field
 def test_anything():
@@ -153,6 +192,12 @@ def objectid_wrong_type_unwrap_test():
     from bson.objectid import ObjectId
     ObjectIdField().unwrap(1)
 
+def test_object_id_auto():
+    from mongoalchemy.document import Document
+    class A(Document):
+        idf = ObjectIdField(auto=True, required=False)
+    assert 'idf' in A().wrap()
+
 #ObjectID Field
 @raises(BadValueException)
 def objectid_wrong_hex_length_test():
@@ -168,6 +213,10 @@ def objectid_value_test():
     oid2 = '4c9e2587eae7dd6064000000'
     assert o.unwrap(o.wrap(oid2)) == oid
 
+    assert o.wrap(o.unwrap(oid.binary)) == oid
+
+    assert isinstance(o.gen(), ObjectId)
+
 
 # TupleField
 @raises(BadValueException)
