@@ -1,6 +1,6 @@
 from nose.tools import *
 from mongoalchemy.session import Session
-from mongoalchemy.document import Document, Index, DocumentField, FieldNotRetrieved
+from mongoalchemy.document import Document, Index, FieldNotRetrieved
 from mongoalchemy.fields import *
 from mongoalchemy.update_expression import InvalidModifierException, UpdateException
 from mongoalchemy.query import BadQueryException, Query, BadResultException, RemoveQuery
@@ -83,6 +83,7 @@ def nested_field_set_test():
     s.query(T2).set('t.i', 3).upsert().execute()
     assert s.query(T2).one().t.i == 3
 
+
 def test_update_safe():
     s = get_session()
     s.clear_collection(TUnique)
