@@ -13,4 +13,4 @@ def test_UNSET():
     # for coverage
     r = repr(UNSET)
     assert UNSET == UNSET
-    assert UNSET != None
\ No newline at end of file
+    assert UNSET is not None
\ No newline at end of file
